@@ -36,7 +36,7 @@ class TutorMagics(Magics):
         code = urllib.parse.urlencode({"code": source})
         display(
             IFrame(
-                f"http://pythontutor.com/iframe-embed.html#{code}&py=3",
+                f"http://pythontutor.com/iframe-embed.html#code={code}&py=3",
                 width,
                 height,
                 extras=['frameborder="0"'],
